# PyFitIt GUI
This project aims to add a graphical user interface to the [PyFitIt](https://github.com/gudasergey/pyFitIt) package. This application currently features:
 - The ability to create project files for the inverse method, including:
     - The ability to add and edit deformations
	 - Basic tooltips for many input fields

<b>NOTE: Most features are still in an unfinished state.</b>

## Installation
In order to install the package, you can use the pip package manager:
```bash
pip install pyfitit-gui
```
or download the source code files. Then, in the source code folder after creating a virtual environment use:
```bash
pip install . 
```
to install the package.

## Usage
After installing, launch the app by typing `pyfitit-gui` in your terminal.

## Documentation
Code documentation is generated via [pdoc](https://pdoc.dev/). This repo also contains a hand-written manual describing PyFitIt, and in the future it will also contatin a chapter on PyFitIt GUI.

## License
This code is availible under the GNU GPL v3 license as stated in the LICENSE file.
